@@ -21,7 +21,6 @@
 #include <QEventLoop>
 #include <QImage>
 #include <QMenu>
-#include <QScreen>
 #include <QThread>
 #include <QTimer>
 #include <QWaylandClientExtensionTemplate>
@@ -274,6 +273,7 @@ WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startS
 
     return startStreaming(stream,
                           {
+                              {QLatin1String("position"), screen->geometry().topLeft()},
                               {QLatin1String("size"), screen->size()},
                               {QLatin1String("source_type"), static_cast<uint>(ScreenCastPortal::Monitor)},
                           });
@@ -295,7 +295,7 @@ WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startS
 
 WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startStreamingRegion(const QRect region, Screencasting::CursorMode mode)
 {
-    return startStreaming(m_screencasting->createRegionStream(region, 1, mode),
+    return startStreaming(m_screencasting->createRegionStream(region, 0, mode),
                           {
                               {QLatin1String("size"), region.size()},
                               {QLatin1String("source_type"), static_cast<uint>(ScreenCastPortal::Monitor)},
@@ -511,3 +511,6 @@ void WaylandIntegration::WaylandIntegrationPrivate::initWayland()
     m_registry->create(connection);
     m_registry->setup();
 }
+
+#include "moc_waylandintegration.cpp"
+#include "moc_waylandintegration_p.cpp"
